@@ -22,13 +22,13 @@
 ## this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn  {statistics} @var{s} = boxplot (@var{data})
-## @deftypefnx {statistics} @var{s} = boxplot (@var{data}, @var{group})
-## @deftypefnx {statistics} @var{s} = boxplot (@var{data}, @var{notched}, @var{symbol}, @var{orientation}, @var{whisker}, @dots{})
-## @deftypefnx {statistics} @var{s} = boxplot (@var{data}, @var{group}, @var{notched}, @var{symbol}, @var{orientation}, @var{whisker}, @dots{})
-## @deftypefnx {statistics} @var{s} = boxplot (@var{data}, @var{options})
-## @deftypefnx {statistics} @var{s} = boxplot (@var{data}, @var{group}, @var{options}, @dots{})
-## @deftypefnx {statistics} [@dots{}, @var{h}] = boxplot (@var{data}, @dots{})
+## @deftypefn  {statistics} {@var{s} =} boxplot (@var{data})
+## @deftypefnx {statistics} {@var{s} =} boxplot (@var{data}, @var{group})
+## @deftypefnx {statistics} {@var{s} =} boxplot (@var{data}, @var{notched}, @var{symbol}, @var{orientation}, @var{whisker}, @dots{})
+## @deftypefnx {statistics} {@var{s} =} boxplot (@var{data}, @var{group}, @var{notched}, @var{symbol}, @var{orientation}, @var{whisker}, @dots{})
+## @deftypefnx {statistics} {@var{s} =} boxplot (@var{data}, @var{options})
+## @deftypefnx {statistics} {@var{s} =} boxplot (@var{data}, @var{group}, @var{options}, @dots{})
+## @deftypefnx {statistics} {[@dots{}, @var{h}] =} boxplot (@var{data}, @dots{})
 ##
 ## Produce a box plot.
 ##
@@ -575,7 +575,7 @@ function [s_o, hs_o] = boxplot (data, varargin)
     ## Skip missing data (NaN, NA) and remove respective sample IDs.
     ## Do this only on nonempty data
     if (length (col) > 0)
-      remove_samples = find (col(isnan (col) | isna (col)));
+      remove_samples = find (isnan (col) | isna (col));
       if (length (remove_samples) > 0)
         col(remove_samples) = [];
         sIDs(remove_samples) = [];
@@ -833,13 +833,22 @@ endfunction
 
 %!demo
 %! axis ([0, 3]);
-%! boxplot ({(randn(10, 1) * 5 + 140), (randn (13, 1) * 8 + 135)});
+%! randn ("seed", 1);    # for reproducibility
+%! girls = randn (10, 1) * 5 + 140;
+%! randn ("seed", 2);    # for reproducibility
+%! boys = randn (13, 1) * 8 + 135;
+%! boxplot ({girls, boys});
 %! set (gca (), "xtick", [1 2], "xticklabel", {"girls", "boys"})
 %! title ("Grade 3 heights");
 
 %!demo
-%! data = [(randn (10, 1) * 5 + 140); (randn (25, 1) * 8 + 135); ...
-%!         (randn (20, 1) * 6 + 165)];
+%! randn ("seed", 7);    # for reproducibility
+%! A = randn (10, 1) * 5 + 140;
+%! randn ("seed", 8);    # for reproducibility
+%! B = randn (25, 1) * 8 + 135;
+%! randn ("seed", 9);    # for reproducibility
+%! C = randn (20, 1) * 6 + 165;
+%! data = [A; B; C];
 %! groups = [(ones (10, 1)); (ones (25, 1) * 2); (ones (20, 1) * 3)];
 %! labels = {"Team A", "Team B", "Team C"};
 %! pos = [2, 1, 3];
@@ -848,11 +857,15 @@ endfunction
 %! title ("Example of Group splitting with paired vectors");
 
 %!demo
-%! boxplot (randn (100, 9), "notch", "on", "boxstyle", "filled", ...
+%! randn ("seed", 1);    # for reproducibility
+%! data = randn (100, 9);
+%! boxplot (data, "notch", "on", "boxstyle", "filled", ...
 %!          "colors", "ygcwkmb", "whisker", 1.2);
 %! title ("Example of different colors specified with characters");
 
 %!demo
+%! randn ("seed", 5);    # for reproducibility
+%! data = randn (100, 13);
 %! colors = [0.7 0.7 0.7; ...
 %!           0.0 0.4 0.9; ...
 %!           0.7 0.4 0.3; ...
@@ -860,11 +873,11 @@ endfunction
 %!           0.8 0.7 0.4; ...
 %!           0.1 0.8 0.5; ...
 %!           0.9 0.9 0.2];
-%! boxplot (randn (100, 13), "notch", "on", "boxstyle", "filled", ...
+%! boxplot (data, "notch", "on", "boxstyle", "filled", ...
 %!          "colors", colors, "whisker", 1.3, "boxwidth", "proportional");
 %! title ("Example of different colors specified as RGB values");
 
-%% Input data validation
+## Input data validation
 %!error <numerical array or cell array containing> boxplot ("a")
 %!error <data cells must contain> boxplot ({[1 2 3], "a"})
 %!error <grouping vector may only be passed> boxplot ([1 2 3], 1, {2, 3})
@@ -897,20 +910,23 @@ endfunction
 %!error <Sample_IDs must match the data> boxplot (randn (10, 3), 'Sample_IDs', {"a", "b"})
 %!error <with the formalism> boxplot (rand (3, 3), [1 2])
 
-## Get current figure visibility so it can be restored after tests
-%!shared visibility_setting
-%! visibility_setting = get (0, "DefaultFigureVisible");
+## Test plotting
 %!test
-%! set (0, "DefaultFigureVisible", "off");
-%! [a, b] = boxplot (rand (10, 3));
-%! assert (size (a), [7, 3]);
-%! assert (numel (b.box), 3);
-%! assert (numel (b.whisker), 12);
-%! assert (numel (b.median), 3);
-%! set (0, "DefaultFigureVisible", visibility_setting);
+%! hf = figure ("visible", "off");
+%! unwind_protect
+%!   [a, b] = boxplot (rand (10, 3));
+%!   assert (size (a), [7, 3]);
+%!   assert (numel (b.box), 3);
+%!   assert (numel (b.whisker), 12);
+%!   assert (numel (b.median), 3);
+%! unwind_protect_cleanup
+%!   close (hf);
+%! end_unwind_protect
 %!test
-%! set (0, "DefaultFigureVisible", "off");
-%! [~, b] = boxplot (rand (10, 3), "BoxStyle", "filled", "colors", "ybc");
-%! assert (numel (b.box_fill), 3);
-%! set (0, "DefaultFigureVisible", visibility_setting);
-
+%! hf = figure ("visible", "off");
+%! unwind_protect
+%!   [~, b] = boxplot (rand (10, 3), "BoxStyle", "filled", "colors", "ybc");
+%!   assert (numel (b.box_fill), 3);
+%! unwind_protect_cleanup
+%!   close (hf);
+%! end_unwind_protect
